configurationtools.update_abjad_user_config_file
================================================

.. autofunction:: abjad.tools.configurationtools.update_abjad_user_config_file.update_abjad_user_config_file
